package cn.iocoder.yudao.module.system.enums.download;

import cn.hutool.core.util.ArrayUtil;
import cn.iocoder.yudao.framework.common.core.IntArrayValuable;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;

/**
 * 错误码的类型枚举
 *
 * @author dylan
 */
@AllArgsConstructor
@Getter
public enum DownloadTypeEnum implements IntArrayValuable {

    /**
     * 订单导出
     */
    ORDER_SEARCH_EXCEL_EXPORT(1),
    /**
     * 控货订单导出
     */
    CARGO_CONTROL_ORDER_SEARCH_EXCEL_EXPORT(2),
    /**
     * 异常订单统计导出
     */
    EXCEPTION_ORDER_STATISTICS_SEARCH_EXCEL_EXPORT(3),
    /**
     * 退仓订单导出
     */
    RETURN_ORDER_SEARCH_EXCEL_EXPORT(4),
    /**
     * 重货订单导出
     */
    HEAVY_ORDER_SEARCH_EXCEL_EXPORT(5),
    /**
     * 售后赔偿订单导出
     */
    SALE_REPAY_ORDER_SEARCH_EXCEL_EXPORT(6),
    /**
     * 报关订单导出
     */
    CUSTOMS_ORDER_SEARCH_EXCEL_EXPORT(7),
    /**
     * 出货订单导出
     */
    SHIPPING_ORDER_SEARCH_EXCEL_EXPORT(8),
    /**
     * 预付订单导出
     */
    ADVANCE_ORDER_SEARCH_EXCEL_EXPORT(9),
    /**
     * 自编号订单导出
     */
    CONTAINER_NUMBER_ORDER_SEARCH_EXCEL_EXPORT(10),

    /**
     * 异常订单导出
     */
    EXCEPTION_ORDER_EXCEL_EXPORT(11),

    /**
     * 预装单导出
     */
    SHIPMENT_PRELOAD_EXCEL_EXPORT(12),

    /**
     * 已装单导出
     */
    SHIPMENT_LOAD_EXCEL_EXPORT(13),

    /**
     * 应收汇总导出
     */
    SHIPMENT_RECEIVABLE_EXCEL_EXPORT(14),

    /**
     * 提单打包下载
     */
    SHIPMENT_BILLING_ZIP_EXPORT(15),

    /**
     * 商品导出
     */
    PRODUCT_EXCEL_EXPORT(16),

    /**
     * 商品价格导出
     */
    PRODUCT_PRICE_EXCEL_EXPORT(17),

    /**
     * 全部客户导出
     */
    CUSTOMER_EXCEL_EXPORT(18),

    /**
     * 我的客户导出
     */
    CUSTOMER_MINE_EXCEL_EXPORT(19),

    /**
     * 我的待接收客户导出
     */
    CUSTOMER_WAIT_CONFIRM_PUBLIC_EXCEL_EXPORT(20),

    /**
     * 公海池客户导出
     */
    CUSTOMER_PUBLIC_EXCEL_EXPORT(21),

    /**
     * 待分配客户导出
     */
    CUSTOMER_WAIT_DISTRIBUTION_PUBLIC_EXCEL_EXPORT(22),

    /**
     * 空运应收模板导出
     */
    AIR_BILL_RECEIVABLE_EXCEL_EXPORT(23),




    /**
     * 潜在客户
     */
    CUSTOMER_POTENTIAL_EXCEL_EXPORT(24),



    /**
     * 间接客户
     */
    CUSTOMER_INDIRECT_EXCEL_EXPORT(25),



    /**
     * 部门客户列表导出
     */
    CUSTOMER_DEPT_EXCEL_EXPORT(26),

    /**
     * 应收报表导出
     */
    SHIPMENT_SUMMERY_EXCEL_EXPORT(27),

    /**
     * 海运预装单导出
     */
    SHIPMENT_SEA_PRELOAD_EXCEL_EXPORT(28),

    /**
     * 空运已装单导出
     */
    SHIPMENT_AIR_LOAD_EXCEL_EXPORT(29),

    /**
     * 业绩明细导出
     */
    ACHIEVEMENT_DETAIL_EXCEL_EXPORT(30),

    /*
     客户分析报表导出 lanbm 2024-05-01 add
     */
    REPORT_CSSTOMER_ANALYSIS(31),

    /*
     销售分析报表导出 lanbm 2024-05-01 add
     */
    REPORT_SALES_ANALYSIS(32),

    // ....自己补充
    ;

    public static final int[] ARRAYS = Arrays.stream(values()).mapToInt(DownloadTypeEnum::getType).toArray();

    /**
     * 类型
     */
    private final Integer type;

    @Override
    public int[] array() {
        return ARRAYS;
    }

    public static DownloadTypeEnum type(Integer type) {
        return ArrayUtil.firstMatch(typeEnum -> typeEnum.getType().equals(type),
                values());
    }
}
